# esbuild-coffeescript

[![esbuild-coffeescript](https://github.com/johnie/esbuild-coffeescript/actions/workflows/master.yml/badge.svg?branch=master)](https://github.com/johnie/esbuild-coffeescript/actions/workflows/master.yml)

> This plugin lets you import [CoffeeScript](https://coffeescript.org/) files when bundling with [Esbuild](https://esbuild.github.io/)

## Installation

```
$ npm install --save-dev esbuild-coffeescript
```

## Getting Started

`main.coffee`

```coffee
answer = 42
console.log("the answer is #{answer}")
```

`build.js`

```js
const coffeeScriptPlugin = require('esbuild-coffeescript');

require('esbuild').build({
  entryPoints: ['main.coffee'],
  bundle: true,
  outfile: 'out.js',
  plugins: [coffeeScriptPlugin()],
});
```

## Configuration

An object containing configuration options may be passed into the plugin constructor `coffeeScriptPlugin`

```js
coffeeScriptPlugin({
  bare: true,
});
```

The following options are available:

- `options.inlineMap`, `boolean`: if true, output the source map as a base64-encoded string in a comment at the bottom.
- `options.filename`, `string`: the filename to use for the source map. It can include a path (relative or absolute).
- `options.bare`, `boolean`: if true, output without the top-level function safety wrapper.
- `options.header`, `boolean`: if true, output the Generated by CoffeeScript header.
- `options.transpile`, `object`: if set, this must be an object with the options to pass to Babel. See [Transpilation](https://coffeescript.org/#transpilation).
- `options.ast`, `boolean`: if true, return an abstract syntax tree of the input CoffeeScript source code.

### But CoffeeScript is dead?

While it might seem like it, coffeescript is still downloaded over 1.6 million times every week. Coffeescript is still actively used and widespread, and this plugin provides a great way for these projects to leverage the great esbuild tooling.
